package com.bipt.intelligentapplicationorchestrationservice.gpu.exception;

import com.bipt.intelligentapplicationorchestrationservice.gpu.model.enums.ErrorCodeEnum;
import com.bipt.intelligentapplicationorchestrationservice.gpu.model.vo.ResponseVO;
import org.springframework.dao.DataAccessResourceFailureException;
import org.springframework.web.bind.MethodArgumentNotValidException;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.RestControllerAdvice;

@RestControllerAdvice
public class GlobalExceptionHandler {
    @ExceptionHandler(DataAccessResourceFailureException.class)
    public ResponseVO handleDBConnectionError() {
        return ResponseVO.error(ErrorCodeEnum.DB_CONNECTION_FAILED);
    }

    @ExceptionHandler(MethodArgumentNotValidException.class)
    public ResponseVO handleValidationError(MethodArgumentNotValidException e) {
        return ResponseVO.error(ErrorCodeEnum.VALIDATION_ERROR);
    }

    @ExceptionHandler(PermissionDeniedException.class)
    public ResponseVO handlePermissionDenied(PermissionDeniedException ex) {
        return ResponseVO.error(ex.getCode(), ex.getMessage());
    }

    @ExceptionHandler(CacheInitException.class)
    public ResponseVO<?> handleCacheInitException(CacheInitException ex) {
        return ResponseVO.error(
                ErrorCodeEnum.CACHE_INIT_ERROR.getCode(),
                "缓存初始化失败: " + ex.getMessage()
        );
    }
}
